<?php
/* ========================================================================
 - [webapp/libs/wap_private.php]
 -      private用WebApplicationクラス
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2006/09/20] $this->base['uri_separator']を追加
 -      [2006/08/26] アカウント情報をメンバ変数に所持
 -      [2006/08/27] ベーステンプレートをコンストラクタで指定
 -      [2006/07/10] 作成
 - ======================================================================== */

require_once LIB_DIR.'rkt_db.php';
require_once LIB_DIR.'rkt_validate.php';
require_once LIB_DIR.'rkt_auth.php';
require_once LIB_DIR.'rkt_webapp.php';

/**
 * private用WebApplicationクラス
 *
 * @author 高橋 裕志郎 <yujiro@stepone.tv>
 * @package WAP_private
 * @access public
 * @version 1.0
 */
class WAP_private extends RKT_webapp
{
    /**
     * アカウント情報
     * @var object
     */
    var $accounts = array();

    /**
     * error情報
     * @var boolean
     */
    var $error = false;

    /**
     * コンストラクタ
     *
     * @access public
     */
    function WAP_private()
    {
        $this->RKT_webapp();
        $this->init_tplargs();

        $objact = account::getInstance();
        $this->account = $objact->getInfo();

        $this->setTemplateBase('base/private.tpl');
        $this->base['menu'] = 'menu/private.tpl';
        $this->addCss('common.css');
        $this->addCss('private.css');
        $this->set_account_info();

        $this->base['account'] = $this->account;
    }

    /**
     * 実行処理
     *
     * @access public
     **/
    function execute()
    {
    }

    /**
     * 表示処理
     *
     * @access public
     * @return void
     **/
    function display()
    {
        if ($this->error){
            $this->template_file = 'error.tpl';
            error_log('WAP_private::error();'."\t".
                        $this->objdb->sqlerror."\r\n", 3, ERROR_LOG_FILE);
        }
        $this->mixOutput();
    }

    /**
     * アカウント情報の設定
     *
     * @access private
     * @return void
     **/
    function set_account_info()
    {
        $sql=
            'SELECT '.
                'act.id as id,'.
                'act.status as status,'.
                'act.friend_number as friend_number,'.
                'pro.nickname as nickname,'.
                'pro.publicity as publicity,'.
                'pht.filename as src,'.
                'pht.width as width,'.
                'pht.height as height,'.
                'pht.thumbnail as t_src,'.
                'pht.t_width as t_width,'.
                'pht.t_height as t_height '.
            'FROM '.
                DB_PREFIX.'act_account act '.
                    'LEFT JOIN '.DB_PREFIX.'act_photo pht '.
                    'ON act.id = pht.ref_account AND '.
                        'pht.status = '.STATUS_PHOTO_MAIN.','.
                DB_PREFIX.'act_profile pro '.
            'WHERE '.
                'act.id = pro.ref_account AND '.
                'act.avail = '.AVAIL_ENABLE.' AND '.
                'act.id = '.$this->account['id'];
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $this->account = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        if (empty($this->account['src'])){
            $this->account['src']      = NOPHOTO_LARGE;
            $this->account['width']    = PHOTO_LARGE_SIZE;
            $this->account['height']   = PHOTO_LARGE_SIZE;
            $this->account['t_src']    = NOPHOTO_SMALL;
            $this->account['t_width']  = PHOTO_SMALL_SIZE;
            $this->account['t_height'] = PHOTO_SMALL_SIZE;
        }
    }

    /**
     * テンプレート引数の初期化
     *
     * @access private
     */
    function init_tplargs()
    {
        $this->base['sid']  = session_id();
        $this->base['url']  = BASE_URL;
        $this->base['http'] = HTTP_ACTION;
        $this->base['ssl']  = SSL_ACTION;

        $this->base['uri_separator'] = htmlspecialchars(WAP_URI_SEPARATOR);
    }

    /**
     * 絵文字エディタ用の初期化設定
     *
     * @access public
     * @return void
     */
    function setEmojiInit()
    {
        $this->addCss('yui_container.css');
        $this->addJavas('YUI/yahoo-min.js');
        $this->addJavas('YUI/event-min.js');
        $this->addJavas('YUI/dom-min.js');
        $this->addJavas('YUI/dragdrop-min.js');
        $this->addJavas('YUI/container-min.js');
        
        $this->base['javascript'] = empty($this->base['javascript'])?'':$this->base['javascript'];

        $init = 
            'YAHOO.namespace("emoji.container");'."\r\n".
            "\r\n".
            'function init() {'."\r\n".
                'YAHOO.emoji.container.panel = new YAHOO.widget.Panel("emoji_table", { width:"240px", visible:false, constraintoviewport:true } );'."\r\n".
                'YAHOO.emoji.container.panel.render();'."\r\n".
                "\r\n".
                'YAHOO.util.Event.addListener("show", "click", YAHOO.emoji.container.panel.show, YAHOO.emoji.container.panel, true);'."\r\n".
                'YAHOO.util.Event.addListener("hide", "click", YAHOO.emoji.container.panel.hide, YAHOO.emoji.container.panel, true);'."\r\n".
            '}'."\r\n".
            "\r\n".
            'YAHOO.util.Event.addListener(window, "load", init);';
        $this->base['javascript'] .= $init;
    }
}
// WAP_privateの終了
?>
